@@ -11,4 +11,4 @@ def test_it_set_status_back_to_loadable_if_httperror(request, mcl):
     request.side_effect = requests.HTTPError("Some issue")
     with pytest.raises(requests.HTTPError):
         apt = mcl.Apartment.query.get(1)
-    assert mcl.state == State.LOADABLE
+    assert mcl.state is State.LOADABLE
